/**
 * @license
 * Copyright 2018 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ChangeDetectorRef, SimpleChanges } from "@angular/core";
import { DocumentService } from "../../_services/document.service";
import { AbstractBaseComponent } from "./base-component";
import { SelectionService } from "../../_services/selection.service";
import { ApiEditorUser } from "../../../../../../models/editor-user.model";
import { CollaboratorService } from "../../_services/collaborator.service";
/**
 * Common base class for collaboration components (overlay and aggregate icon).
 */
export declare abstract class AbstractCollaboratorComponent extends AbstractBaseComponent {
    private collaboratorService;
    nodePath: string | string[];
    private _open;
    left: string;
    top: string;
    private _collaborators;
    private _collabSub;
    /**
     * C'tor.
     * @param changeDetectorRef
     * @param documentService
     * @param selectionService
     * @param collaboratorService
     */
    protected constructor(changeDetectorRef: ChangeDetectorRef, documentService: DocumentService, selectionService: SelectionService, collaboratorService: CollaboratorService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    protected onDocumentChange(): void;
    /**
     * Update the list of collaborators for the currently configured node path.
     */
    protected updateCollaborators(): void;
    open(event: MouseEvent): void;
    close(): void;
    isOpen(): boolean;
    hasCollaborators(): boolean;
    collaborators(): ApiEditorUser[];
    iconColorFor(collaborator: ApiEditorUser): string;
}
export declare class CollaboratorOverlayComponent extends AbstractCollaboratorComponent {
    /**
     * C'tor.
     * @param changeDetectorRef
     * @param documentService
     * @param selectionService
     * @param collaboratorService
     */
    constructor(changeDetectorRef: ChangeDetectorRef, documentService: DocumentService, selectionService: SelectionService, collaboratorService: CollaboratorService);
    overlayColor(): string;
}
