/**
 * @license
 * Copyright 2017 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ElementRef, EventEmitter, QueryList } from "@angular/core";
import { ModalDirective } from "ngx-bootstrap";
import { OasDocument } from "apicurio-data-models";
export declare class AddPathDialogComponent {
    onAdd: EventEmitter<string>;
    addPathModal: QueryList<ModalDirective>;
    addPathInput: QueryList<ElementRef>;
    private _isOpen;
    path: string;
    paths: string[];
    pathExists: boolean;
    /**
     * Called to open the dialog.
     * @param document
     * @param path
     */
    open(document: OasDocument, path?: string): void;
    /**
     * Called to close the dialog.
     */
    close(): void;
    /**
     * Called when the user clicks "add".
     */
    add(): void;
    /**
     * Called when the user clicks "cancel".
     */
    cancel(): void;
    /**
     * Returns true if the dialog is open.
     * @return
     */
    isOpen(): boolean;
    /**
     * Called to initialize the selection/focus to the addPathInput field.
     */
    doSelect(): void;
    /**
     * Called whenever the user types anything in the path field - this validates that the path entered
     * is OK.
     * @param newPath
     */
    validatePath(newPath: string): void;
}
