/**
 * @license
 * Copyright 2017 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ChangeDetectorRef } from "@angular/core";
import { OasContact, OasDocument } from "apicurio-data-models";
import { CommandService } from "../../../_services/command.service";
import { AbstractBaseComponent } from "../../common/base-component";
import { DocumentService } from "../../../_services/document.service";
import { SelectionService } from "../../../_services/selection.service";
export declare class ContactSectionComponent extends AbstractBaseComponent {
    private changeDetectorRef;
    private documentService;
    private commandService;
    private selectionService;
    document: OasDocument;
    constructor(changeDetectorRef: ChangeDetectorRef, documentService: DocumentService, commandService: CommandService, selectionService: SelectionService);
    /**
     * Returns true if the API has Contact Info defined.
     */
    hasContact(): boolean;
    /**
     * Returns the current contact object.
     */
    contact(): OasContact;
    /**
     * Called to add empty contact info to the API definition.
     */
    createEmptyContact(): void;
    /**
     * Called when the user chooses to remove the contact info.
     */
    deleteContact(): void;
    /**
     * Returns the contact name.
     */
    contactName(): string;
    /**
     * Returns the contact email.
     */
    contactEmail(): string;
    /**
     * Returns the contact url.
     */
    contactUrl(): string;
    /**
     * Called when the user changes the contact name.
     * @param newValue
     */
    changeContactName(newValue: string): void;
    /**
     * Called when the user changes the contact email.
     * @param newValue
     */
    changeContactEmail(newValue: string): void;
    /**
     * Called when the user changes the contact url.
     * @param newValue
     */
    changeContactURL(newValue: string): void;
}
