/**
 * @license
 * Copyright 2017 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ChangeDetectorRef } from "@angular/core";
import { OasDocument, SecurityScheme } from "apicurio-data-models";
import { CommandService } from "../../../_services/command.service";
import { EditorsService } from "../../../_services/editors.service";
import { SecurityScheme20Data, SecurityScheme30Data } from "../../editors/security-scheme-editor.component";
import { AbstractBaseComponent } from "../../common/base-component";
import { DocumentService } from "../../../_services/document.service";
import { SelectionService } from "../../../_services/selection.service";
import { RenameEntityDialogComponent, RenameEntityEvent } from "../../dialogs/rename-entity.component";
export declare class SecuritySchemesSectionComponent extends AbstractBaseComponent {
    private changeDetectorRef;
    private documentService;
    private commandService;
    private editors;
    private selectionService;
    document: OasDocument;
    renameDialog: RenameEntityDialogComponent;
    /**
     * C'tor.
     * @param changeDetectorRef
     * @param documentService
     * @param commandService
     * @param editors
     * @param selectionService
     */
    constructor(changeDetectorRef: ChangeDetectorRef, documentService: DocumentService, commandService: CommandService, editors: EditorsService, selectionService: SelectionService);
    /**
     * Opens the security scheme dialog.
     * @param scheme
     */
    openSecuritySchemeModal(scheme?: SecurityScheme): void;
    /**
     * Returns true if there is at least one security scheme defined.
     * @return
     */
    hasSecuritySchemes(): boolean;
    /**
     * Returns all defined security schemes.
     * @return
     */
    securitySchemes(): SecurityScheme[];
    /**
     * Node path that is the base for all security schemes.
     */
    securitySchemesPath(): string;
    /**
     * Called when the user adds a new security scheme.
     * @param event
     */
    addSecurityScheme(event: SecurityScheme20Data | SecurityScheme30Data): void;
    /**
     * Called when the user changes an existing security scheme.
     * @param event
     */
    changeSecurityScheme(event: SecurityScheme20Data | SecurityScheme30Data): void;
    /**
     * Deletes a security scheme.
     * @param scheme
     */
    deleteSecurityScheme(scheme: SecurityScheme): void;
    /**
     * Converts from array of scopes to scopes object for data model.
     * @param scopes
     */
    private toScopes;
    /**
     * Copy the event data to the data model.
     * @param event
     * @param scheme
     */
    private copySchemeToModel;
    /**
     * Called when the user clicks the trash icon to delete all the servers.
     */
    deleteAllSecuritySchemes(): void;
    /**
     * Opens the rename security scheme dialog.
     * @param scheme
     */
    openRenameDialog(scheme: SecurityScheme): void;
    /**
     * Renames the security scheme.
     * @param event
     */
    rename(event: RenameEntityEvent): void;
}
