/**
 * @license
 * Copyright 2017 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ChangeDetectorRef } from "@angular/core";
import { OasDocument, OasTag } from "apicurio-data-models";
import { CommandService } from "../../../_services/command.service";
import { AbstractBaseComponent } from "../../common/base-component";
import { DocumentService } from "../../../_services/document.service";
import { SelectionService } from "../../../_services/selection.service";
import { RenameEntityDialogComponent, RenameEntityEvent } from "../../dialogs/rename-entity.component";
export declare class TagsSectionComponent extends AbstractBaseComponent {
    private changeDetectorRef;
    private documentService;
    private commandService;
    private selectionService;
    document: OasDocument;
    renameDialog: RenameEntityDialogComponent;
    /**
     * C'tor.
     * @param changeDetectorRef
     * @param documentService
     * @param commandService
     * @param selectionService
     */
    constructor(changeDetectorRef: ChangeDetectorRef, documentService: DocumentService, commandService: CommandService, selectionService: SelectionService);
    /**
     * Returns the list of tags defined in the document.
     * @return
     */
    tags(): OasTag[];
    /**
     * Called when the user changes the description of a tag.
     * @param tag
     * @param description
     */
    changeTagDescription(tag: OasTag, description: string): void;
    /**
     * Called when the user chooses to delete a tag.
     * @param tag
     */
    deleteTag(tag: OasTag): void;
    /**
     * Called when the user clicks 'Add' on the Add Tag modal dialog.
     * @param tag
     */
    addTag(tag: any): void;
    /**
     * Returns true if the document has at least one tag defined.
     */
    hasTags(): boolean;
    /**
     * Called when the user clicks the trash icon to delete all the tags.
     */
    deleteAllTags(): void;
    /**
     * Opens the rename tag dialog.
     * @param tag
     */
    openRenameDialog(tag: OasTag): void;
    /**
     * Renames the tag.
     * @param event
     */
    rename(event: RenameEntityEvent): void;
}
