/**
 * @license
 * Copyright 2017 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ChangeDetectorRef, QueryList, SimpleChanges } from "@angular/core";
import { Oas20Operation, Oas30Operation } from "apicurio-data-models";
import { InlineArrayEditorComponent } from "../../../common/inline-array-editor.component";
import { CommandService } from "../../../../_services/command.service";
import { AbstractBaseComponent } from "../../../common/base-component";
import { DocumentService } from "../../../../_services/document.service";
import { SelectionService } from "../../../../_services/selection.service";
export declare class OperationInfoSectionComponent extends AbstractBaseComponent {
    private changeDetectorRef;
    private documentService;
    private commandService;
    private selectionService;
    operation: Oas20Operation | Oas30Operation;
    consumesEditor: QueryList<InlineArrayEditorComponent>;
    producesEditor: QueryList<InlineArrayEditorComponent>;
    private _operationInfoPaths;
    private _showInheritedConsumes;
    private _showInheritedProduces;
    /**
     * C'tor.
     * @param changeDetectorRef
     * @param documentService
     * @param commandService
     * @param selectionService
     */
    constructor(changeDetectorRef: ChangeDetectorRef, documentService: DocumentService, commandService: CommandService, selectionService: SelectionService);
    ngOnChanges(changes: SimpleChanges): void;
    _initConsumesProduces(): void;
    /**
     * Returns the node paths of all the properties editable in this section.
     */
    operationInfoPaths(): string[];
    /**
     * Called when the user changes the summary.
     * @param newSummary
     */
    changeSummary(newSummary: string): void;
    /**
     * Called when the user changes the description.
     * @param newDescription
     */
    changeDescription(newDescription: string): void;
    /**
     * Called when the user changes the operationId.
     * @param newOperationId
     */
    changeOperationId(newOperationId: string): void;
    /**
     * Called when the user changes the tags.
     * @param newTags
     */
    changeTags(newTags: string[]): void;
    /**
     * Called when the user changes the "consumes".
     * @param newValue
     */
    onConsumesChange(newValue: string[]): void;
    /**
     * Called when the user closes the consumes editor without making changes.
     */
    onConsumesClose(): void;
    /**
     * Called when the user changes the "produces".
     * @param newValue
     */
    onProducesChange(newValue: string[]): void;
    /**
     * Called when the user closes the produces editor without making changes.
     */
    onProducesClose(): void;
    consumes(): string[];
    produces(): string[];
    hasGlobalConsumes(): boolean;
    hasLocalConsumes(): boolean;
    hasLocalProduces(): boolean;
    showInheritedConsumes(): boolean;
    inheritedConsumes(): string[];
    hasGlobalProduces(): boolean;
    showInheritedProduces(): boolean;
    inheritedProduces(): string[];
    overrideConsumes(): void;
    overrideProduces(): void;
    tagDefs(): () => string[];
    is2xDocument(): boolean;
}
