/**
 * @license
 * Copyright 2018 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Node } from "apicurio-data-models";
import { ChangeDetectorRef, ElementRef } from "@angular/core";
import { AbstractBaseComponent } from "../../common/base-component";
import { DocumentService } from "../../../_services/document.service";
import { CommandService } from "../../../_services/command.service";
import { SelectionService } from "../../../_services/selection.service";
export declare class SectionComponent extends AbstractBaseComponent {
    private commandService;
    static allVisibleSections: SectionComponent[];
    type: string;
    label: string;
    expanded: boolean;
    counterItems: any[];
    contextHelp: string;
    validationModels: Node[];
    validationShallow: boolean;
    validationProperties: string[];
    collaborationNodePath: string | string[];
    inForm: boolean;
    sectionHeader: ElementRef;
    sectionBody: ElementRef;
    showContextMenu: boolean;
    contextMenuPos: any;
    private _highlightSubscription;
    showHighlight: boolean;
    /**
     * C'tor.
     * @param changeDetectorRef
     * @param documentService
     * @param commandService
     * @param selectionService
     */
    constructor(changeDetectorRef: ChangeDetectorRef, documentService: DocumentService, commandService: CommandService, selectionService: SelectionService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Returns true if the given path is "contained within" this section.
     * @param path
     */
    protected acceptsPath(path: string): boolean;
    /**
     * Briefly? highlight this section (visually).
     */
    highlight(): void;
    hasCounter(): boolean;
    hasValidationAggregate(): boolean;
    toggleExpansion(): void;
    openContextMenu(event: MouseEvent): void;
    closeContextMenu(): void;
    collapseAllOtherSections(): void;
    collapse(): void;
    expand(): void;
    collapseAllSections(): void;
    expandAllSections(): void;
    /**
     * Called whenever the user presses a key.
     * @param event
     */
    onGlobalKeyDown(event: KeyboardEvent): void;
    onDocumentClick(event: MouseEvent): void;
}
