/**
 * @license
 * Copyright 2017 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ChangeDetectorRef } from "@angular/core";
import { Oas30Document, Oas30Operation, Oas30PathItem, Oas30Server } from "apicurio-data-models";
import { CommandService } from "../../../_services/command.service";
import { EditorsService } from "../../../_services/editors.service";
import { ServerData, ServerEditorEvent } from "../../editors/server-editor.component";
import { AbstractBaseComponent } from "../../common/base-component";
import { DocumentService } from "../../../_services/document.service";
import { SelectionService } from "../../../_services/selection.service";
export declare class ServersSectionComponent extends AbstractBaseComponent {
    private changeDetectorRef;
    private documentService;
    private commandService;
    private editorsService;
    private selectionService;
    parent: Oas30Document | Oas30PathItem | Oas30Operation;
    collapsed: boolean;
    description: string;
    showSectionBody: boolean;
    constructor(changeDetectorRef: ChangeDetectorRef, documentService: DocumentService, commandService: CommandService, editorsService: EditorsService, selectionService: SelectionService);
    ngOnInit(): void;
    /**
     * Returns the list of global servers defined in the document.
     * @return
     */
    servers(): Oas30Server[];
    serversPath(): string;
    /**
     * Called when the user chooses to delete a server.
     * @param server
     */
    deleteServer(server: Oas30Server): void;
    /**
     * Called when the user adds a new server.
     * @param data
     */
    addServer(data: ServerData): void;
    /**
     * Called when the user edits an existing server.
     * @param event
     */
    changeServer(event: ServerEditorEvent): void;
    /**
     * Opens the full screen modal "server editor" so that advanced editing of the
     * server can be accomplished.
     */
    onAddServer(): void;
    /**
     * Copies the data from the event to the new server model.
     * @param fromData
     * @param toServer
     */
    private copyServerToModel;
    hasServers(): boolean;
    /**
     * Called when the user clicks the trash icon to delete all the servers.
     */
    deleteAllServers(): void;
}
