export interface ILicense {
    id: string;
    name: string;
    fullName: string;
    description: string;
    url: string;
    moreInfoUrl: string;
    permissions: string[];
    conditions: string[];
    limitations: string[];
}
/**
 * A simple service providing convenient access to information about different
 * licenses commonly used to license APIs.
 */
export declare class LicenseService {
    /**
     * Returns a list of all licenses.
     *
     */
    getLicenses(): ILicense[];
    /**
     * Resolves a permission code into a name.
     * @param permission
     */
    permissionName(permission: string): string;
    /**
     * Resolves a permission code into a description.
     * @param permission
     */
    permissionDescription(permission: string): string;
    /**
     * Resolves a condition code into a name.
     * @param condition
     */
    conditionName(condition: string): string;
    /**
     * Resolves a condition code into a description.
     * @param condition
     */
    conditionDescription(condition: string): string;
    /**
     * Resolves a limitation code into a name.
     * @param limitation
     */
    limitationName(limitation: string): string;
    /**
     * Resolves a limitation code into a description.
     * @param limitation
     */
    limitationDescription(limitation: string): string;
    /**
     * Finds a license by its URL.  Multiple URLs may resolve to the same
     * license.
     * @param url
     * @return
     */
    findLicense(url: string): ILicense;
}
