/**
 * @license
 * Copyright 2017 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Oas20SchemaDefinition, Oas30SchemaDefinition, CombinedVisitorAdapter } from "apicurio-data-models";
/**
 * Visitor used to find schema definitions.
 */
export declare class FindSchemaDefinitionsVisitor extends CombinedVisitorAdapter {
    private filterCriteria;
    schemaDefinitions: (Oas20SchemaDefinition | Oas30SchemaDefinition)[];
    /**
     * C'tor.
     * @param filterCriteria
     */
    constructor(filterCriteria: string);
    /**
     * Called when a schema definition is visited.
     * @param node
     */
    visitSchemaDefinition(node: Oas20SchemaDefinition | Oas30SchemaDefinition): void;
    /**
     * Sorts and returns the path items.
     */
    getSortedSchemaDefinitions(): (Oas20SchemaDefinition | Oas30SchemaDefinition)[];
    /**
     * Figures out the definition name regardless of the version of the model.
     * @param definition
     */
    static definitionName(definition: Oas20SchemaDefinition | Oas30SchemaDefinition): string;
    /**
     * Returns true if the given name is accepted by the current filter criteria.
     * @param name
     */
    private acceptThroughFilter;
}
