/**
 * @license
 * Copyright 2019 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from "@angular/core";
import { ApiDefinition } from "../../../../models/api.model";
import { AaiDocument, ICommand, IValidationSeverityRegistry, OtCommand, OtEngine, ValidationProblem } from "apicurio-data-models";
import { VersionedAck } from "../../../../models/ack.model";
import { ApiEditorUser } from "../../../../models/editor-user.model";
import { SelectionService } from "./_services/selection.service";
import { CommandService } from "./_services/command.service";
import { DocumentService } from "./_services/document.service";
import { EditorsService } from "./_services/editors.service";
import { ApiEditorComponentFeatures } from "./_models/features.model";
import { FeaturesService } from "./_services/features.service";
import { CollaboratorService } from "./_services/collaborator.service";
import { AbstractApiEditorComponent } from "./editor.base";
import { CodeEditorMode, CodeEditorTheme } from "../../../../components/common/code-editor.component";
export declare class AsyncApiEditorComponent extends AbstractApiEditorComponent implements OnChanges, OnInit, OnDestroy {
    private selectionService;
    private commandService;
    private documentService;
    private editorsService;
    private featuresService;
    private collaboratorService;
    api: ApiDefinition;
    embedded: boolean;
    features: ApiEditorComponentFeatures;
    validationRegistry: IValidationSeverityRegistry;
    onCommandExecuted: EventEmitter<OtCommand>;
    onSelectionChanged: EventEmitter<string>;
    onValidationChanged: EventEmitter<ValidationProblem[]>;
    onUndo: EventEmitter<OtCommand>;
    onRedo: EventEmitter<OtCommand>;
    onConfigureValidation: EventEmitter<void>;
    private _document;
    private _otEngine;
    _undoableCommandCount: number;
    _redoableCommandCount: number;
    sourceOriginal: string;
    sourceValue: string;
    sourceIsValid: boolean;
    validationErrors: ValidationProblem[];
    private _selectionSubscription;
    private _commandSubscription;
    /**
     * Constructor.
     * @param selectionService
     * @param commandService
     * @param documentService
     * @param editorsService
     * @param featuresService
     * @param collaboratorService
     */
    constructor(selectionService: SelectionService, commandService: CommandService, documentService: DocumentService, editorsService: EditorsService, featuresService: FeaturesService, collaboratorService: CollaboratorService);
    /**
     * Called when the editor is initialized by angular.
     */
    ngOnInit(): void;
    /**
     * Called when angular destroys the editor component.
     */
    ngOnDestroy(): void;
    /**
     * Called when the @Input changes.
     * @param changes
     */
    ngOnChanges(changes: SimpleChanges): void;
    sourceTheme(): CodeEditorTheme;
    sourceMode(): CodeEditorMode;
    isDirty(): boolean;
    /**
     * Gets the spec as a document.
     */
    document(): AaiDocument;
    /**
     * Lazy getter for the OtEngine.
     */
    otEngine(): OtEngine;
    /**
     * Called whenever the user presses a key.
     * @param event
     */
    onGlobalKeyDown(event: KeyboardEvent): void;
    /**
     * Called when the user clicks the Undo button or uses the Ctrl-z hotkey.
     */
    undoLastCommand(): void;
    /**
     * Called when the user clicks the Redo button or uses the Ctrl-y hotkey.
     */
    redoLastCommand(): void;
    /**
     * Called when an editor component creates a command that should be executed.
     * @param command
     */
    protected onCommand(command: ICommand): void;
    /**
     * Executes a command.  Called by the parent of this component when detecting that
     * another user has executed a command.  In other words, this command is *not*
     * performed by the local user.
     * @param command
     */
    executeCommand(command: OtCommand): void;
    /**
     * Call this to undo a command.  Typically this is used to undo commands from
     * remote collaborators after receiving an async message from the server.
     * @param command
     */
    undoCommand(command: OtCommand | number | string): void;
    /**
     * Call this to redo a command.  Typically this is used to undo commands from
     * remote collaborators after receiving an async message from the server.
     * @param command
     */
    redoCommand(command: OtCommand | number): void;
    /**
     * Finalizes a command.
     * @param ack
     */
    finalizeCommand(ack: VersionedAck): void;
    /**
     * Called to update the selection state of the given remote API editor (i.e. an active collaborator).
     * @param user
     * @param selection
     */
    updateCollaboratorSelection(user: ApiEditorUser, selection: string): void;
    /**
     * Called when the user selects a node in some way.
     * @param path
     */
    onNodeSelected(path: string): void;
    /**
     * Called to validate the model.
     */
    validateModel(): void;
    preDocumentChange(): void;
    postDocumentChange(): void;
    /**
     * Called to get the current value in the editor.
     * @return
     */
    getValue(): ApiDefinition;
    select(path: string, highlight?: boolean): void;
    /**
     * Called when the user clicks save.
     */
    saveSource(): void;
    /**
     * Called when the user clicks revert.
     */
    revertSource(): void;
    /**
     * Validates that the current source text is valid.
     */
    validate(): void;
}
